tests._utils module — justbases 0.07 documentation

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »

# tests._utils module

Test utilities.

`tests._utils.` `build_base`(max_base)

  Builds a base.

  Parameters: | max_base (int) – the maximum base

`tests._utils.` `build_base_config`()

  Build base config.

`tests._utils.` `build_display_config`(base_config, digits_config, strip_config)

  Builds a well-formed display configuration.

  Parameters: | base_config (BaseConfig) – the base config digits_config (DigitsConfig) – the digits config strip_config (StripConfig) – the strip config

`tests._utils.` `build_nat`(base, max_len)

  Build a well-formed nat strategy from `base`.

`tests._utils.` `build_radix`(max_base, max_len)

  Build a well-formed Radix strategy.

  Parameters: | max_base (int) – maximum value for a numeric base max_len (int) – the maximum length for the component lists

`tests._utils.` `build_relation`()

  Build a sign value.

`tests._utils.` `build_sign`()

  Build a sign value.

`tests._utils.` `build_strip_config`()

  Build strip config.

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »